package This::Namespace::Is::Mine::Ha::Ha;

use strict;
use warnings;

use version;our $VERSION = qv('0.0.1');

1;
__END__

=pod

=head1 NAME

This::Namespace::Is::Mine::Ha::Ha - [One line description of module's purpose here]

=head1 SYNOPSIS

	use This::Namespace::Is::Mine::Ha::Ha;

=head1 USING THE This::Namespace::Is::Mine::Ha::Ha:: namespace

If you'd like to use the This::Namespace::Is::Mine::Ha::Ha namespace in your
modules, please use This::Namespace::Is::Mine::Ha::Ha::3rdparty,
This::Namespace::Is::Mine::Ha::Ha::Custom,
This::Namespace::Is::Mine::Ha::Ha::Local, or
This::Namespace::Is::Mine::Ha::Ha::My as your base namespace to avoid confusion
with modules released by me.

Thank you very much for your consideration in this matter.

